pyprocar.core.Structure — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.core.Structure

class pyprocar.core.Structure(atoms=None, cartesian_coordinates=None, fractional_coordinates=None, lattice=None, rotations=None)

  Class to define a peridic crystal structure.

  Parameters:

    - atoms (list str) – A list of atomic symbols, with the same order as the `fractional_coordinates`.

    - fractional_coordinates (list (n,3) float.) – A (natom,3) list of fractional coordinatesd of atoms.

    - lattice (list (3,3) float.) – A (3,3) matrix representing the lattice vectors.

  Returns:

    None.

  Methods

  `Structure.__init__`([atoms, ...]) |
  `Structure.get_space_group_international`([...]) | Returns the international Space Group Number of the material
  `Structure.get_space_group_number`([symprec]) | Returns the Space Group Number of the material
  `Structure.get_spglib_symmetry_dataset`([symprec]) | Returns the spglib symmetry dataset
  `Structure.get_wyckoff_positions`([symprec]) | Returns the wyckoff positions
  `Structure.is_point_inside`(point[, lattice]) | A method to determine if a point is inside the unitcell
  `Structure.plot_cell_convex_hull`() | A method to plot the the convex hull
  `Structure.supercell`(matrix) | A method to transform the Structure to a supercell
  `Structure.transform`([transformation_matrix]) | Transform the crystla lattice by a transformation matrix

  Attributes

  `Structure.a` | The magnitude of the first crystal lattice vector
  `Structure.alpha` | The angle between the of the second and third crystal lattice vectors
  `Structure.atomic_numbers` | List of atomic numbers
  `Structure.b` | The magnitude of the second crystal lattice vector
  `Structure.beta` | The angle between the of the first and third crystal lattice vectors
  `Structure.c` | The magnitude of the third crystal lattice vector
  `Structure.cell_convex_hull` | Returns the cell convex hull
  `Structure.density` | Density of the cell.
  `Structure.gamma` | The angle between the of the first and second crystal lattice vectors
  `Structure.lattice_corners` | Returns the corners of the crystal lattice
  `Structure.masses` | list of masses of each atom.
  `Structure.natoms` | Number of atoms
  `Structure.nspecies` | Number of species present in the cell.
  `Structure.reciprocal_lattice` | The reciprocal lattice matrix corresponding the the crystal lattice
  `Structure.species` | list of different species present in the cell.
  `Structure.volume` | Volume of the unit cell.